var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { AccessLevel, Gender } from './IUser';
import { Api } from '../../Api';
import { ExalusConnectionService } from '../ExalusConnectionService';
import { DataFrame, Method, Status } from '../../DataFrame';
import { User } from './User';
import { DependencyContainer } from '../../DependencyContainer';
import { ResponseResult } from '../FieldChangeResult';
export class UsersService {
    constructor() {
        this._connection = null;
        this._connection = Api.Get(ExalusConnectionService.ServiceName);
    }
    GetServiceName() {
        return UsersService.ServiceName;
    }
    GetUsersAsync() {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield ((_a = this._connection) === null || _a === void 0 ? void 0 : _a.SendAndWaitForResponseAsync(new GetUsersListRequest(), 20000, false));
            if (result === null || result === undefined)
                return Promise.resolve([]);
            if ((result === null || result === void 0 ? void 0 : result.Status) == Status.OK) {
                if (result.Data != null) {
                    const users = [];
                    result.Data.forEach(element => {
                        var user = new User();
                        user.AccessLevel = element.AccessLevel;
                        user.Email = element.Email;
                        user.Gender = element.Gender;
                        user.Guid = element.Guid;
                        user.IsAccountOnline = element.IsAccountOnline;
                        user.Name = element.Name;
                        user.IsActive = element.IsActive;
                        user.IsBanned = element.IsBanned;
                        user.Phone = element.Phone;
                        user.Surname = element.Surname;
                        users.push(user);
                    });
                    return users;
                }
                else
                    return Promise.resolve([]);
            }
            else if ((result === null || result === void 0 ? void 0 : result.Status) == Status.NoData)
                return Promise.resolve([]);
            else {
                (_b = DependencyContainer.Log) === null || _b === void 0 ? void 0 : _b.Debug(UsersService.ServiceName, `Failed to retrieve users, error: ${result.Status}`);
                throw new Error(`Failed to retrieve users, error: ${result.Status}`);
            }
        });
    }
    GetUserAsync(id) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            if (id === "")
                return Promise.resolve(null);
            else if (id == null)
                id = "";
            const result = yield ((_a = this._connection) === null || _a === void 0 ? void 0 : _a.SendAndWaitForResponseAsync(new GetUserRequest(id), 20000, false));
            if (result == null || result.Data == null)
                return Promise.resolve(null);
            if (result.Status != Status.OK) {
                (_b = DependencyContainer.Log) === null || _b === void 0 ? void 0 : _b.Debug(UsersService.ServiceName, `Failed to retrieve user, error: ${result.Status}`);
                return Promise.resolve(null);
            }
            const user = new User();
            user.AccessLevel = result.Data.AccessLevel;
            user.Email = result.Data.Email;
            user.Gender = result.Data.Gender;
            user.Guid = result.Data.Guid;
            user.IsAccountOnline = result.Data.IsAccountOnline;
            user.Name = result.Data.Name;
            user.IsActive = result.Data.IsActive;
            user.IsBanned = result.Data.IsBanned;
            user.Phone = result.Data.Phone;
            user.Surname = result.Data.Surname;
            return user;
        });
    }
    CreateUserAsync(user, password) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            if (user.Guid != null && user.Guid != "")
                return new ResponseResult(Status.WrongData, "GuidMustBeEmpty");
            const userRequest = new UserDataFrame();
            userRequest.Name = user.Name.trim();
            userRequest.Surname = user.Surname.trim();
            userRequest.Email = user.Email.trim();
            userRequest.Password = password.trim();
            userRequest.Phone = user.Phone.trim();
            userRequest.Gender = user.Gender;
            userRequest.AccessLevel = user.AccessLevel;
            const result = yield ((_a = this._connection) === null || _a === void 0 ? void 0 : _a.SendAndWaitForResponseAsync(new SetUserRequest(userRequest), 20000, false));
            if (result == null || result.Status == null)
                return new ResponseResult(Status.FatalError, "UnknownError");
            if (result.Data == null)
                result.Data = "";
            return new ResponseResult(result.Status, result.Data);
        });
    }
    UpdateUserAsync(user) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            if (user.Guid == null || user.Guid == "")
                return new ResponseResult(Status.WrongData, "GuidCannotBeEmpty");
            const userRequest = new UserDataFrame();
            userRequest.Guid = user.Guid;
            userRequest.Name = user.Name.trim();
            userRequest.Surname = user.Surname.trim();
            userRequest.Email = user.Email.trim();
            userRequest.Phone = user.Phone.trim();
            userRequest.Gender = user.Gender;
            userRequest.AccessLevel = user.AccessLevel;
            const result = yield ((_a = this._connection) === null || _a === void 0 ? void 0 : _a.SendAndWaitForResponseAsync(new SetUserRequest(userRequest), 20000, false));
            if (result == null || result.Status == null)
                return new ResponseResult(Status.FatalError, "UnknownError");
            if (result.Data == null)
                result.Data = "";
            return new ResponseResult(result.Status, result.Data);
        });
    }
    ChangePasswordAsync(user, password) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            if (user.Guid == null || user.Guid == "")
                return new ResponseResult(Status.WrongData, "GuidCannotBeEmpty");
            const currentUser = yield this.GetUserAsync(user.Guid);
            if (currentUser == null)
                return new ResponseResult(Status.ResourceIsNotAvailable, "CannotGetUser");
            const passRequest = new UserDataFrame();
            passRequest.Guid = user.Guid;
            passRequest.Password = password;
            passRequest.AccessLevel = currentUser.AccessLevel;
            passRequest.Email = currentUser.Email;
            const result = yield ((_a = this._connection) === null || _a === void 0 ? void 0 : _a.SendAndWaitForResponseAsync(new SetUserRequest(passRequest), 20000, false));
            if (result == null || result.Status == null)
                return new ResponseResult(Status.FatalError, "UnknownError");
            if (result.Data == null)
                result.Data = "";
            return new ResponseResult(result.Status, result.Data);
        });
    }
    DeleteUserAsync(id) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            if (id === "")
                return Status.WrongData;
            else if (id == null)
                id = "";
            const result = yield ((_a = this._connection) === null || _a === void 0 ? void 0 : _a.SendAndWaitForResponseAsync(new DeleteUserRequest(id), 20000, false));
            if (result == null || result.Status == null)
                return Status.FatalError;
            if (result.Status != Status.OK)
                (_b = DependencyContainer.Log) === null || _b === void 0 ? void 0 : _b.Debug(UsersService.ServiceName, `Failed to delete user, error: ${result.Status}`);
            return result.Status;
        });
    }
}
UsersService.ServiceName = "UsersService";
class GetUserRequest extends DataFrame {
    constructor(userGuid) {
        super();
        this.Resource = "/users/user";
        this.Method = Method.Get;
        this.Data = userGuid;
    }
}
class UserDataFrame {
    constructor() {
        this.Guid = "";
        this.Name = "";
        this.Surname = "";
        this.Email = "";
        this.Password = "";
        this.Phone = "";
        this.Gender = Gender.Unknown;
        this.AccessLevel = AccessLevel.Any;
    }
}
class SetUserRequest extends DataFrame {
    constructor(user) {
        super();
        this.Resource = "/users/user";
        this.Method = Method.Put;
        this.Data = user;
    }
}
class GetUsersListRequest extends DataFrame {
    constructor() {
        super();
        this.Resource = "/users/list";
        this.Method = Method.Get;
    }
}
class DeleteUserRequest extends DataFrame {
    constructor(userGuid) {
        super();
        this.Resource = "/users/user";
        this.Method = Method.Delete;
        this.Data = userGuid;
    }
}
//# sourceMappingURL=UsersService.js.map